@@ -49,7 +49,7 @@ gboolean timer_handler(gpointer data){
 #ifdef PC_EMULATOR    
     temp_string = ctime(&current_time);
     fprintf(stderr,"\nCurrent Time: %s\n",  temp_string);
-//    g_free(temp_string);
+/*    g_free(temp_string);*/
     print_list();
 #endif	
     while(list_time_event_temp != NULL){
@@ -59,9 +59,20 @@ gboolean timer_handler(gpointer data){
 		case DAYTIMEEVENT :
      		    weather_frame_update(FALSE);   
 		break;
+		case DBUSINITEVENT:
+		#ifdef PC_EMULATOR
+		    fprintf(stderr,"DBUSINITEVENT %s\n",ctime(&evt->time));
+		#endif
+		    g_free(evt);
+                    event_time_list = g_slist_remove(event_time_list, event_time_list->data);
+		    weather_initialize_dbus();
+		break;    
 		default:
 		case AUTOUPDATE:
 		    /* delete periodic update */
+		#ifdef PC_EMULATOR
+		    fprintf(stderr,"Delete evt %s\n",ctime(&evt->time));
+		#endif
 		    g_free(evt);
                     event_time_list = g_slist_remove(event_time_list, event_time_list->data);
 		#ifdef PC_EMULATOR
@@ -90,11 +101,13 @@ void print_list(void){
     if(!event_time_list)
 	return;
     list_time_event_temp = event_time_list;
+    fprintf(stderr, "\n");
     while(list_time_event_temp){
 	evt = list_time_event_temp->data;
 	fprintf(stderr,"Event %i Time: %s", evt->type_event, ctime(&evt->time));
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
+    fprintf(stderr, "\n");
 }
 #endif
 
@@ -109,16 +122,29 @@ void free_list_time_event(void){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
     
+    #ifdef PC_EMULATOR
+    fprintf(stderr,"Free ALL in list\n");
+    print_list();
+    #endif
     if(!event_time_list)
 	return;
     list_time_event_temp = event_time_list; 
     while(list_time_event_temp != NULL){
+        #ifdef PC_EMULATOR
+	fprintf(stderr,"delete\n");
+	#endif
 	evt = list_time_event_temp->data;
 	g_free(evt);
+/*	list_time_event_temp = g_slist_remove(list_time_event_temp, list_time_event_temp->data);*/
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
     g_slist_free(event_time_list);
     event_time_list = NULL;
+    #ifdef PC_EMULATOR
+    fprintf(stderr,"list clean\n");
+    print_list();
+    #endif
+
 }
 
 /* Compare function for sort event list */
@@ -134,16 +160,39 @@ static gint compare_time(gconstpointer a, gconstpointer b){
 void time_event_add(time_t time_value, short type_event){
     struct event_time *evt;
 
-    evt = g_new0(struct event_time, 1);
-    evt->time = time_value;	  
-    evt->type_event = type_event;
-    event_time_list = g_slist_insert_sorted(event_time_list,evt,compare_time);
+    #ifdef PC_EMULATOR
+    fprintf(stderr,"time_event_add in list\n");
+    print_list();
+    #endif
+    if( time_value && time_value > time(NULL) ){
+	evt = g_new0(struct event_time, 1);
+	evt->time = time_value;	  
+	evt->type_event = type_event;
+	event_time_list = g_slist_insert_sorted(event_time_list,evt,compare_time);
+    }
+    #ifdef PC_EMULATOR
+    fprintf(stderr,"time_event_add in list finished\n");
+    print_list();
+    #endif
+    
 }
 
 /* Add periodic time event  to list */	  
 void add_periodic_event(time_t last_update){
+
+    #ifdef PC_EMULATOR
+    fprintf(stderr,"Add in list\n");
+    print_list();
+    #endif
+
     if(app->update_interval > 0)
 	time_event_add(last_update + app->update_interval * 60, AUTOUPDATE);
+
+    #ifdef PC_EMULATOR
+    fprintf(stderr,"Item added to list\n");
+    print_list();
+    #endif
+	
 }
 
 /* Remove periodic time event  from list */	  
@@ -151,16 +200,25 @@ void remove_periodic_event(void){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
     
+    #ifdef PC_EMULATOR
+    fprintf(stderr,"Periodic remove from list\n");
+    print_list();
+    #endif
+
     if(!event_time_list)
 	return;
-    list_time_event_temp = event_time_list;  
+    list_time_event_temp = event_time_list;
     while(list_time_event_temp != NULL){
 	evt = list_time_event_temp->data;
 	if(evt->type_event == AUTOUPDATE){
-	    event_time_list = g_slist_remove(event_time_list, event_time_list->data);
-	    list_time_event_temp = event_time_list;  
 	    g_free(evt);
+	    list_time_event_temp = g_slist_remove(list_time_event_temp, list_time_event_temp->data);
 	}
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
+    event_time_list = list_time_event_temp;
+    #ifdef PC_EMULATOR
+    fprintf(stderr,"Periodic is remove from list\n");
+    print_list();
+    #endif
 }
