@@ -208,10 +208,10 @@ void weather_buttons_fill(gboolean check_error){
 	break;
     }
     
+
 /* Init weather buttons */
     weather_buttons_init();
     count_day = parse_weather_com_xml();
-
     if(check_error)
 	if(count_day == -2){
 	    count_day = 0;
@@ -223,10 +223,6 @@ void weather_buttons_fill(gboolean check_error){
     tm = localtime(&current_day);
     tm->tm_sec = 0; tm->tm_min = 0; tm->tm_hour = 0;
     current_day = mktime(tm);
-/* free time event list */
-    free_list_time_event();
-/* add periodic update */
-    add_periodic_event(time(NULL));
 /* Search day of saving xml near current day */
     while( (offset < Max_count_weather_day) &&
 	    (current_day > weather_days[offset].date_time) &&
@@ -234,15 +230,16 @@ void weather_buttons_fill(gboolean check_error){
 	offset ++;
     for(i = 0; i < app->days_to_show; i++, offset++){
      /* If it first button add to evenet time change between nigth and day */
-	if(current_day == weather_days[offset].date_time){
+	if((offset < count_day ) &&
+	   (current_day == weather_days[offset].date_time)){
 	    if(current_time < weather_days[offset].day.begin_time)
 		time_event_add(weather_days[offset].day.begin_time,DAYTIMEEVENT);
 	    if(current_time < weather_days[offset].night.begin_time)  
 		time_event_add(weather_days[offset].night.begin_time,DAYTIMEEVENT);
 	}
     /* Time event add to event list */
-	if( (current_day < weather_days[offset].date_time) &&
-	    (offset < count_day ) ){
+	if( (offset < count_day) &&
+	    (current_day < weather_days[offset].date_time) ){
 	    time_event_add(weather_days[offset].date_time,DAYTIMEEVENT);  /* Add time event  to list */	  
 	    last_day = weather_days[offset].date_time;	  
 	}      
@@ -257,7 +254,6 @@ void weather_buttons_fill(gboolean check_error){
 		temp_low = c2f(temp_low);
 	    }  
      /* Show current weather or forecast */
-
 	    if( (i==0) && 
 		(weather_current_day.date_time>(current_time-OFFSET_CURRENT_WEATHER*3600)) &&
                 (weather_current_day.date_time<(current_time+OFFSET_CURRENT_WEATHER*3600))){
@@ -271,7 +267,8 @@ void weather_buttons_fill(gboolean check_error){
 	    }		
     	    else{
       /* Show forecast */
-		if(current_day == weather_days[offset].date_time){
+		if((offset < count_day) &&
+		   (current_day == weather_days[offset].date_time)){
        /* First icon - night(morning) or day or night (evening) */     
 		    if(current_time<weather_days[offset].day.begin_time){  
     			sprintf(buffer_icon,"%s%i.png",path_large_icon,weather_days[offset].night.icon);
@@ -318,13 +315,15 @@ void weather_buttons_fill(gboolean check_error){
 	    } 
 	}
      /* Write offset in wetaher data for this button */
-	boxs_offset[i] = offset;
+        if(offset < count_day)
+	    boxs_offset[i] = offset;
+	else 
+	    boxs_offset[i] = Max_count_weather_day;
      /* Prepare butons for view */   
 	app->buttons[i] = create_weather_day_button(buffer, buffer_icon, icon_size, app->transparency, font_size);
 	g_signal_connect(app->buttons[i]->button, "released", G_CALLBACK(weather_window_popup_show), NULL);
 	g_signal_connect(app->buttons[i]->button, "enter", G_CALLBACK(enter_button), NULL); 
     }/* for */
-
     if(g_slist_length(stations_view_list) > 0){
 	tmplist = stations_view_list;
 /* search current station */
@@ -346,13 +345,12 @@ void weather_buttons_fill(gboolean check_error){
     create_panel(app->main_window, app->icons_layout, app->transparency, tmp_station_name, font_size);
     gtk_box_pack_start(GTK_BOX(app->top_widget), app->main_window, TRUE, TRUE, 0);
     gtk_widget_show_all(app->top_widget);
-
     if(error_station_code)
 	station_error_window();
 }
 
 void weather_frame_update(gboolean check){
-    
+
     free_memory(FALSE);
     if (app->main_window)
         gtk_widget_destroy(app->main_window);
@@ -396,16 +394,20 @@ void* hildon_home_applet_lib_initialize(void *state_data,
     app->distance_units = KILOMETERS;
     app->wind_units = METERS_S;
     app->temperature_units = CELSIUS;
+    app->dbus_is_initialize = FALSE;
 /* Init gconf. */
     gnome_vfs_init();
     read_config();
 /* Start timer */
     timer();
-/* Initialize DBUS */
-    weather_initialize_dbus();
 /* Start main applet */ 
     app->top_widget = gtk_hbox_new(FALSE, 0);
     weather_buttons_fill(FALSE);
+/* Initialize DBUS */
+/*    weather_initialize_dbus();*/
+    time_event_add(time(NULL) + 5, DBUSINITEVENT);    
+    add_periodic_event(time(NULL));
+    
     (*widget) = app->top_widget;
     return (void*)osso;
 }
@@ -444,6 +446,8 @@ void hildon_home_applet_lib_deinitialize(void *applet_data){
     #endif
     /* It is switch off the timer */	
     check = g_source_remove(app->timer);
+    /* Clean the queue of event */ 
+    free_list_time_event();
     /* If downloading then switch off it */
     if (app->flag_updating != 0){
 	check = g_source_remove(app->flag_updating);
@@ -607,6 +611,7 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
     gtk_container_set_focus_child(GTK_CONTAINER(panel), station_name_btn); 
     if(station_name_btn)
 	g_object_unref(station_name_btn);
+
 }
 
 /* free used memory from OMWeather struct */
