@@ -217,14 +217,15 @@ GSList* prepare_idlist(void){
 /* Initialize all configuration from GCONF.  This should not be called more
  * than once during execution. */
 void read_config(void){
-    gchar	*tmp;
-    GConfValue	*value;
+    gchar	*tmp = NULL;
+    GConfValue	*value = NULL;
+    GConfClient *gconf_client = NULL;
     int		fd = -1;
     GSList	*stlist = NULL;
     GError	*gerror = NULL;
     GdkColor	DEFAULT_FONT_COLOR = {0, 0x0d00, 0x2a00, 0xc000};
     
-    GConfClient *gconf_client = gconf_client_get_default();
+    gconf_client = gconf_client_get_default();
 
     if(!gconf_client){
         fprintf(stderr, _("Failed to initialize GConf. Quitting.\n"));
@@ -322,30 +323,28 @@ void read_config(void){
 				: (app->temperature_units = CELSIUS);
     /* Get Temperature Unit  Default Celsius */
     /* Depricated, after 0.18 not used */
-    if (gerror){
+    if(gerror){
         tmp = gconf_client_get_string(gconf_client,
-                     GCONF_KEY_WEATHER_TEMPERATURE_UNIT,NULL);
+                     GCONF_KEY_WEATHER_TEMPERATURE_UNIT, NULL);
 	if(tmp){
-	    if (tmp[0] == 'C')
+	    if(tmp[0] == 'C')
 		app->temperature_units = CELSIUS;
 	    else
-		{
 		app->temperature_units = FAHRENHEIT;
-		}
 	    g_free(tmp);
 	}
 	else
 	    app->temperature_units = CELSIUS;	  
 	g_error_free(gerror);
 	gerror = NULL;
-    }	
+    }
 
     /* Depricated, after 0.18 not used */
     app->icons_layout = gconf_client_get_int(gconf_client,
                 			    GCONF_KEY_WEATHER_LAYOUT,
 					    NULL);
     
-    if (app->icons_layout == 0)
+    if(app->icons_layout == 0)
 	    /* Get Layout  Default Horizontal */
 	    app->icons_layout = gconf_client_get_int(gconf_client,
                 			    GCONF_KEY_ICONS_LAYOUT,
@@ -357,6 +356,7 @@ void read_config(void){
 	app->days_to_show = 5;
 	g_error_free(gerror);
     }
+    app->previos_days_to_show = app->days_to_show;
     /* Get distance units */
     app->distance_units = gconf_client_get_int(gconf_client,                                                                                     
                 	    GCONF_KEY_WEATHER_DISTANCE_UNITS, &gerror);
@@ -373,18 +373,22 @@ void read_config(void){
     }
     /* Fill time update list */
     if(!time_update_list){
-	add_time_update_list(0, _("Never"));	
+	add_time_update_list(0, _("Never"));
+	add_time_update_list(5, _("5 minutes"));
+	add_time_update_list(30, _("30 minutes"));
 	add_time_update_list(1 * 60, _("1 hour"));
 	add_time_update_list(2 * 60, _("2 hours"));
 	add_time_update_list(4 * 60, _("4 hours"));
 	add_time_update_list(8 * 60, _("8 hours"));
 	add_time_update_list(24 * 60, _("24 hours"));
-	add_time_update_list(1, _("1 minute (DEBUG)"));    
+/* #ifdef PC_EMULATOR */
+	add_time_update_list(1, _("1 minute (DEBUG)"));
+/* #endif */
     }
     /* Check connection */
     tmp = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_CURRENT_CONNECTIVITY, NULL);
-    if (tmp){
+    if(tmp){
         app->iap_connected = TRUE;
 	g_free(tmp);
     }	
@@ -393,6 +397,7 @@ void read_config(void){
 	
     app->show_update_window = FALSE;
     gconf_client_clear_cache(gconf_client);
+    g_object_unref(gconf_client);
 }
 
 void config_update_proxy(void){
