@@ -45,7 +45,7 @@ CURL* weather_curl_init(CURL *curl_handle);
 gboolean download_html(gpointer data);
 void weather_initialize_dbus(void);
 gboolean check_connected(void);
-void clean_download ();
+void clean_download(void);
 GtkWidget *update_window = NULL;     
 
 struct HtmlFile {
