@@ -33,10 +33,8 @@
 
 #include "weather-home_common.h"
 
-extern gchar *_weather_dir_name;
-extern gchar *_weather_station_id;
-
 weather_com_parser *weather_parser_new_from_file(const gchar *filename);
 int parse_weather_com_xml(void);
-
+char* get_short_name(const char* name, gboolean what);
+void split_date(char* str, int *day);
 #endif
