@@ -703,6 +703,10 @@ void weather_window_preference(GtkWidget *widget,
     flag_update_icon = FALSE;
     flag_tuning_warning = FALSE; 
 
+    if (!app->dbus_is_initialize)
+			weather_initialize_dbus();
+
+
     window_config = gtk_dialog_new_with_buttons(_("Other Maemo Weather Settings"),
         				NULL,
 					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -864,7 +868,6 @@ void weather_window_preference(GtkWidget *widget,
     font_color = gtk_color_button_new();
     gtk_container_add(GTK_CONTAINER(label), font_color);
     gtk_color_button_set_color(GTK_COLOR_BUTTON(font_color), &(app->font_color));
-    gtk_widget_show(font_color);
     /* Transparency */
     gtk_table_attach_defaults(GTK_TABLE(table),	    
         			label = gtk_label_new(_("Transparency")),
@@ -1077,8 +1080,8 @@ void weather_window_preference(GtkWidget *widget,
 	    }
 	break;
       }
-     if  (result_gtk_dialog_run !=  GTK_RESPONSE_HELP) 
-        break; /* We  leave a cycle WHILE */
+	if(result_gtk_dialog_run !=  GTK_RESPONSE_HELP) 
+    	    break; /* We  leave a cycle WHILE */
     }
     not_event = FALSE;
     if(flag_tuning_warning)
@@ -1167,7 +1170,11 @@ void create_help_dialog(void){
 	    "Greg Thompson for support stations.txt file\n"
 	    "Frank Persian - for idea of new layout\n"
 	    "Brian Knight - for idea of iconset, criticism \n"
-	    "\t\t\t\tand donation ;-)\n"));
+	    "\t\t\t\tand donation ;-)\n"
+	    "Andrew aka Tabster - for testing and ideas\n"
+	    "Brad Jones aka kazrak - for testing\n"
+	    "Eugene Roytenberg - for testing\n"
+	    "Jarek Szczepanski aka Imrahil - for testing\n"));
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
         			create_scrolled_window_with_text(tmp_buff,
 						    GTK_JUSTIFY_LEFT),
@@ -1217,6 +1224,7 @@ void station_list_view_select_handler(GtkTreeView *tree_view,
     GtkTreeSelection	*selected_line;
     GtkTreeModel	*model;
 
+
     selected_line = gtk_tree_view_get_selection(GTK_TREE_VIEW(tree_view));
     model = gtk_tree_view_get_model(GTK_TREE_VIEW(tree_view));
     if( !gtk_tree_selection_get_selected(selected_line, NULL, &iter) )
