@@ -46,6 +46,8 @@ popup_window_event_cb(GtkWidget *widget,
 }
 
 void pre_update_weather(void){
+    if (!app->dbus_is_initialize)
+	weather_initialize_dbus();
     app->show_update_window = TRUE;
     update_weather();
 }
@@ -81,7 +83,6 @@ void weather_window_popup_show(GtkWidget *widget,
     } 
    /* Search: Which button pressed */
     for(i = 0;i < app->days_to_show; i++)
-//	if(buttons[i] == widget) 
 	if(app->buttons[i]->button == widget) 
 	    break;  
     /* Not found pressed button */
